'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
var baseOptions = exports.baseOptions = {
  tags: {
    p: {},
    br: false,
    b: {},
    strong: {},
    i: {},
    em: {},
    strike: {},
    ol: {},
    ul: {},
    li: {},
    a: { href: true, target: true },
    h2: {},
    h3: {},
    u: {}
  }
};

var baseTextOptions = exports.baseTextOptions = Object.assign({}, baseOptions, {
  tags: Object.assign({}, baseOptions.tags, {
    blockquote: {}
  })
});

var baseInlineOptions = exports.baseInlineOptions = {
  tags: {
    br: false,
    b: {},
    strong: {},
    em: {},
    i: {},
    u: {},
    a: { href: true, target: true },
    strike: {}
  }
};

var toolbarButtons = exports.toolbarButtons = [{
  command: 'bold',
  icon: 'bold'
}, {
  command: 'italic',
  icon: 'italic'
}, {
  command: 'underline',
  icon: 'underline'
}, {
  command: 'link',
  icon: 'link'
}, {
  command: 'h3',
  icon: 'header'
}];

var normalizeLink = function normalizeLink(link) {
  if (link.indexOf('http://') === 0 || link.indexOf('https://') === 0) {
    return link;
  }
  if (link.indexOf('@') >= 0) {
    return 'mailto:' + link;
  }
  if (link.indexOf('+') == 0) {
    return 'tel:' + link;
  }
  return 'http://' + link;
};

var linkCommand = exports.linkCommand = function linkCommand() {
  return function (scribe) {
    var linkPromptCommand = new scribe.api.Command('createLink');
    linkPromptCommand.nodeName = 'A';

    linkPromptCommand.execute = function (passedLink) {
      var _this = this;

      var selection = new scribe.api.Selection();
      var range = selection.range;
      var anchorNode = selection.getContaining(function (node) {
        return node.nodeName === _this.nodeName;
      });

      // const initialLink = anchorNode ? anchorNode.href : '';
      if (anchorNode) {
        range.selectNode(anchorNode);
        selection.selection.removeAllRanges();
        selection.selection.addRange(range);
      }
      if (passedLink) {
        scribe.api.SimpleCommand.prototype.execute.call(this, normalizeLink(passedLink));
      }
    };

    linkPromptCommand.queryState = function () {
      var selection = new scribe.api.Selection();
      return !!selection.getContaining(function (node) {
        return node.nodeName === this.nodeName;
      }.bind(this));
    };

    linkPromptCommand.getCurrentLink = function () {
      var _this2 = this;

      var selection = new scribe.api.Selection();
      var range = selection.range;
      var anchorNode = selection.getContaining(function (node) {
        return node.nodeName === _this2.nodeName;
      });
      return anchorNode ? anchorNode.href : '';
    };

    scribe.commands.setLink = linkPromptCommand;
  };
};

var isEditorEmpty = exports.isEditorEmpty = function isEditorEmpty(scribe) {
  var childNodes = scribe.el.childNodes;
  var blockCount = childNodes.length;

  if (blockCount === 0) {
    return true;
  } else if (blockCount === 1) {
    var node = childNodes[0];
    var nodeName = node.nodeName.toLowerCase();

    if (nodeName === 'p' && node.textContent === '') {
      return true;
    }
  }

  return false;
};

var defaultCommands = exports.defaultCommands = {
  // bold: (e) => ((e.metaKey || e.ctrlKey) && e.which === 66),
  // italic: (e) => ((e.metaKey || e.ctrlKey) && e.which === 73),
  h3: function h3(e) {
    return (e.metaKey || e.ctrlKey) && e.which === 51;
  } };

var keyboardPlugin = exports.keyboardPlugin = function keyboardPlugin() {
  var commandsToKeyboardShortcutsMap = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultCommands;
  return function (scribe) {

    scribe.el.addEventListener('keydown', function (event) {
      var commandName = '';
      for (var key in commandsToKeyboardShortcutsMap) {
        if (commandsToKeyboardShortcutsMap.hasOwnProperty(key)) {
          if (commandsToKeyboardShortcutsMap[key](event)) {
            commandName = key;
            break;
          }
        }
      }

      if (commandName) {
        var command = scribe.getCommand(commandName);
        event.preventDefault();

        if (command.queryEnabled()) {
          command.execute();
        }
      }
    });
  };
};