'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.CustomPasteHandler = undefined;

var _MediumEditor$extensi;

exports.dumbToSmartQuotes = dumbToSmartQuotes;

var _mediumEditor = require('medium-editor');

var _mediumEditor2 = _interopRequireDefault(_mediumEditor);

var _htmlJanitor = require('html-janitor');

var _htmlJanitor2 = _interopRequireDefault(_htmlJanitor);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var janitorConfig = {
  tags: {
    p: {},
    a: {
      href: true,
      target: true
    },
    strong: {},
    b: {},
    em: {},
    i: {},
    u: {},
    br: {},
    strike: {},
    h2: {},
    h3: {},
    h4: {},
    h5: {},
    h6: {},
    ul: {},
    li: {}
  }
};

var janitor = new _htmlJanitor2.default(janitorConfig);

function dumbToSmartQuotes(str) {
  str = str.replace(/([a-zA-Z0-9.,?!;:\'\"])\"/g, '$1”');
  str = str.replace(/\"/g, '“');
  str = str.replace(/=“(.*?)”/g, '="$1"');

  str = str.replace(/([a-zA-Z0-9.,?!;:\"\'])\'/gi, '$1’');
  str = str.replace(/\'/g, '‘');
  str = str.replace(/=‘(.*?)’/g, "='$1'");
  return str;
}

function getClipboardContent(event, win, doc) {
  var dataTransfer = event.clipboardData || win.clipboardData || doc.dataTransfer,
      data = {};

  if (!dataTransfer) {
    return data;
  }

  // Use old WebKit/IE API
  if (dataTransfer.getData) {
    var legacyText = dataTransfer.getData('Text');
    if (legacyText && legacyText.length > 0) {
      data['text/plain'] = legacyText;
    }
  }

  if (dataTransfer.types) {
    for (var i = 0; i < dataTransfer.types.length; i++) {
      var contentType = dataTransfer.types[i];
      data[contentType] = dataTransfer.getData(contentType);
    }
  }

  return data;
}

var CustomPasteHandler = exports.CustomPasteHandler = _mediumEditor2.default.extensions.paste.extend((_MediumEditor$extensi = {
  cleanPastedHTML: true,
  forcePlainText: true
}, _defineProperty(_MediumEditor$extensi, 'cleanPastedHTML', true), _defineProperty(_MediumEditor$extensi, 'cleanReplacements', [[/<!--[^>]*-->/gi, '']]), _defineProperty(_MediumEditor$extensi, 'cleanAttrs', ['class', 'dir', 'style', 'name', 'id']), _defineProperty(_MediumEditor$extensi, 'cleanTags', ['label', 'meta', 'aside', 'h1', 'span', 'code', 'pre', 'img', 'code']), _defineProperty(_MediumEditor$extensi, 'handlePaste', function handlePaste(event) {
  event.preventDefault();
  var html = '';
  var data = getClipboardContent(event, this.window, this.document);
  var pastedHTML = data['text/html'];
  var pastedPlain = data['text/plain'];
  console.log(pastedHTML);
  if (!pastedHTML) {
    _mediumEditor2.default.extensions.paste.prototype.handlePaste.apply(this, arguments);
    return;
  } else {
    html = dumbToSmartQuotes(janitor.clean(pastedHTML));
  }
  if (html) {
    this.pasteHTML(html);
  }
}), _defineProperty(_MediumEditor$extensi, 'handlePasteBinPaste', function handlePasteBinPaste(event) {
  event.preventDefault();
  this.removePasteBin();
  var html = '';
  var data = getClipboardContent(event, this.window, this.document);
  var pastedHTML = data['text/html'];
  var pastedPlain = data['text/plain'];
  if (!pastedHTML) {
    _mediumEditor2.default.extensions.paste.prototype.handlePaste.apply(this, arguments);
    return;
  } else {
    html = dumbToSmartQuotes(janitor.clean(pastedHTML));
  }
  if (html) {
    this.pasteHTML(html);
  }
}), _MediumEditor$extensi));

// export const AutoList = MediumEditor.Extension.extend({
//   name: 'autolist',
//   init: function(){
//     this.subscribe('editableKeypress', this.onKeypress.bind(this));
//   },
//   onKeypress: function (keyPressEvent) {
//    if (MediumEditor.util.isKey(keyPressEvent, [MediumEditor.util.keyCode.SPACE])) {
//       var list_start = this.base.getSelectedParentElement().textContent;
//       console.log(list_start);
//       console.log(this.base.getExtensionByName('orderedlist'));
//       if (list_start == "1."){
//         console.log(this.base.getSelectedParentElement());
//         this.base.execAction('insertorderedlist');
//         this.base.getSelectedParentElement().textContent = this.base.getSelectedParentElement().textContent.slice(2).trim();
//       }
//       else if( list_start == "*"){
//         this.base.execAction('insertunorderedlist');
//         this.base.getSelectedParentElement().textContent = this.base.getSelectedParentElement().textContent.slice(1).trim();
//       }
//     }
//   },
// });


var getConfig = function getConfig() {
  return {
    toolbar: {
      buttons: ['bold', 'italic', 'underline', 'anchor', 'strikethrough']
    },
    autoLink: false,
    imageDragging: false,
    placeholder: {
      text: 'Write your story...'
    },
    paste: {
      forcePlainText: true,
      cleanPastedHTML: true,
      cleanReplacements: [[/<!--[^>]*-->/gi, '']],
      cleanAttrs: ['class', 'dir', 'style', 'name', 'id'],
      cleanTags: ['label', 'meta', 'aside', 'span']
    },
    disableExtraSpaces: false,
    extensions: {
      imageDragging: {},
      paste: new CustomPasteHandler()
    }
  };
};

exports.default = getConfig;